﻿using System;
using NUnit.Framework;
using NUnit.Framework.SyntaxHelpers;
using OpenQA.Selenium.Firefox;

namespace Selenium.Examples
{
    public class Tests
    {
        private FirefoxDriver _driver;
        private SeleniumHelpers _seleniumHelpers;

        [SetUp]
        public void Setup()
        {
            _driver = new FirefoxDriver();
            _driver.Manage().Timeouts().ImplicitlyWait(new TimeSpan(0, 0, 30));
        }

        [Test]
        public void NotifyTable_NumberOfRows_ShouldEqualTwo()
        {
            _driver.Navigate().GoToUrl("http://www.deanhume.com");

            _seleniumHelpers = new SeleniumHelpers(_driver);

            int numberOfRowsInTable = _seleniumHelpers.GetNumberOfRowsInTable("notify-table");

            Assert.That(numberOfRowsInTable, Is.EqualTo(2));
        }

        [Test]
        public void SelectList_NumberOfOptions_ShouldEqualFour()
        {
            _driver.Navigate().GoToUrl("http://deanhume.com/select.html");

            _seleniumHelpers = new SeleniumHelpers(_driver);

            var numberOfOptionsInSelect = _seleniumHelpers.GetNumberOfOptionsInSelect("CarList");

            Assert.That(numberOfOptionsInSelect, Is.EqualTo(4));
        }

        #region TearDown

        [TearDown]
        public void FixtureTearDown()
        {
            if (_driver != null) _driver.Close();
        }

        #endregion
    }
}
